<?
/**
 * dbAttribute
 * This class represents an attribute of an object from the database.
 */
class dbAttribute {

  /**
   * Name of the attribute as it is in the database
   * @var String
   */
  public $sName;
  
  /**
   * Value that indicates if the attribute is a primary key
   * @var boolean
   */
  public $bPrimaryKey = false;

  /**
   * Value of the attribute as it is in the database
   * @var Unknown
   */
  public $uValue;
  
  /**
   * Position of the attribute in the database
   * @var Integer
   */
  public $iPosition;
  
  /**
   * Default value of the attribute as it is in the database
   * @var Unknown
   */
  public $uDefault;
  
  /**
   * Boolean used to check if the attribute is nullable or not in the database
   * @var Boolean
   */
  public $bNull;
  
  /**
   * Type of the attribute in the database
   * @var String
   */
  public $sType;
  
  /**
   * Maximum length of the content of the attribute in the database
   * @var Integer
   */
  public $iMaxLength;
  
  /**
   * Characterset of the attribute in the database
   * @var String
   */
  public $sCharacterSet;
  
  /**
   * Type of the attribute as defined in the column in the database
   * @var String
   */
  public $sColumnType;

 /**
   * Type of the attribute as defined in the column in the database
   * @var Boolean
   */
  public $bForeignKey;

  /**
   * Constructor of an attribute, values are set to null, dbObject does the rest (for speeding purposes)
   */
  public function dbAttribute() {
    $this->sName=null;
    $this->uValue=null;
    $this->iPosition=null;
    $this->uDefault=null;
    $this->bNull=null;
    $this->sType=null;
    $this->iMaxLength=null;
    $this->sCharacterSet=null;
    $this->sColumnType=null;
    $this->bForeignKey=null;
  }
  
  /**
   * When saving an attribute, the mysql string depends on the type of the attribute
   * @return (uValue) String for updating the database for this specific attribute
   */
  public function formatQuotes() {
    
    // The default save string is NULL, as this is a valid option if the attribute is nullable, for speeding purposes this is checked in dbObject
    $__uValue = "NULL";
    

    // If the object has a value, NULL this value has to be saved (unless there is a default, which is returned in getvalue)
    if($this->getvalue()) {
    
      // The syntax of the save string depends on the type of the file
      switch($this->sType) {
      
	// All types of dates have to be formatted for MySQL
        case 'date':
        case 'datetime':
        case 'time':
        case 'timestamp':
          if(is_object($this->getValue())) $__uValue = "'".$this->getValue()->format('c')."'";
          else {
            $oDate = new DateTime($this->getValue());
            $__uValue = "'".$oDate->format('c')."'";
          }
          break;
          
        // Floats and decimals have to contain dots instead of commas
        case 'float':
        case 'decimal':
          $__uValue = str_replace(',','.',$this->getValue());
          break;
          
        // All kind of integers can be saved as they are
        case 'bigint':
        case 'int':
        case 'tinyint':
          $__uValue = $this->getValue();
          break;
        default:
        
	  // Other filetypes have to be escaped
          $__uValue = "'".mysql_real_escape_string($this->getValue())."'";
          break;
      }
    }
    if($this->bPrimaryKey) $__uValue = $this->getValue();
    return $__uValue;
  }
 
 
  /**
   * function to set the value of the attribute
   * @param(uValue) Unknown filetype, depends on the type of the attribute. The value that has to be set
   */
  public function setValue($uValue) {
  
    // The way the attribute have to be set depends on the type of the attribute
    switch($this->sType) {
    
      // For all date types
      case 'date':
      case 'datetime':
      case 'time':
      case 'timestamp':
      
        if(!$uValue) $this->uValue = null;
        // If it is already an object, the value can be set
        else if(is_object($uValue)) {
          $this->uValue = $uValue;
        // If the value is numeric, the value can be set using a new datetime
        } elseif(is_numeric($uValue)) {
          $this->uValue = new DateTime(date('c',$uValue));
        // If the value is a string, the value can be set using a new datetime
        } else {
          if($uValue == 'Invalid Date') break;
          $this->uValue = $uValue;
          //$this->uValue = new DateTime($uValue);
        }
        break;
      default:
	// All other types can be set as they are
        $this->uValue = $uValue;
        break;
    }
  }
  
  /**
   * function to set the value of the attribute to null
   */
  public function setNull() {
    $this->uValue = null;
  }

  /**
   * Function to get the value of the attribute
   * @return(uValue) value of the attribute
   */
  public function getValue() {
    // The way the attribute have to be returned depends on their type
    switch($this->sType) {
    
      // For all date types
      case 'date':
      case 'datetime':
      case 'time':
      case 'timestamp':
      
        if(!$this->uValue) return null;
        // If it is already an object, the value can be set
        else if(is_object($this->uValue)) {
          return $this->uValue;
        // If the value is numeric, the value can be returned
        } elseif(is_numeric($this->uValue)) {
          return new DateTime(date('c',$this->uValue));
        // If the value is a string, the value can be returned
        } else {
          return new DateTime($this->uValue);
        }
        break;
      default:
	// All other types can be get as they are
       return $this->uValue?$this->uValue:($this->bPrimaryKey?0:$this->uDefault);
       break;
    }
    
    
    
  }
}
?>